@@ -546,7 +546,7 @@ pango_font_description_set_variations_static (PangoFontDescription *desc,
 /**
  * pango_font_description_set_variations:
  * @desc: a `PangoFontDescription`.
- * @variations: a string representing the variations
+ * @variations: (nullable): a string representing the variations
  *
  * Sets the variations field of a font description.
  *
@@ -1270,7 +1270,8 @@ parse_variations (const char  *word,
  * "Normal", "Roman", "Oblique", "Italic".
  *
  * The following words are understood as variants:
- * "Small-Caps".
+ * "Small-Caps", "All-Small-Caps", "Petite-Caps", "All-Petite-Caps",
+ * "Unicase", "Title-Caps".
  *
  * The following words are understood as weights:
  * "Thin", "Ultra-Light", "Extra-Light", "Light", "Semi-Light",
@@ -1491,7 +1492,8 @@ pango_font_description_to_string (const PangoFontDescription *desc)
         g_string_append (result, "px");
     }
 
-  if (desc->variations && desc->mask & PANGO_FONT_MASK_VARIATIONS)
+  if ((desc->variations && desc->mask & PANGO_FONT_MASK_VARIATIONS) &&
+      desc->variations[0] != '\0')
     {
       g_string_append (result, " @");
       g_string_append (result, desc->variations);
@@ -1750,6 +1752,13 @@ pango_font_default_get_face (PangoFont *font)
   return PANGO_FONT_MAP_GET_CLASS (map)->get_face (map,font);
 }
 
+static void
+pango_font_default_get_matrix (PangoFont   *font,
+                               PangoMatrix *matrix)
+{
+  *matrix = (PangoMatrix) PANGO_MATRIX_INIT;
+}
+
 static void
 pango_font_class_init (PangoFontClass *class G_GNUC_UNUSED)
 {
@@ -1765,6 +1774,7 @@ pango_font_class_init (PangoFontClass *class G_GNUC_UNUSED)
   pclass->get_scale_factors = pango_font_default_get_scale_factors;
   pclass->has_char = pango_font_default_has_char;
   pclass->get_face = pango_font_default_get_face;
+  pclass->get_matrix = pango_font_default_get_matrix;
 }
 
 static void
@@ -2716,6 +2726,15 @@ pango_font_get_languages (PangoFont *font)
   return pclass->get_languages (font);
 }
 
+void
+pango_font_get_matrix (PangoFont   *font,
+                       PangoMatrix *matrix)
+{
+  PangoFontClassPrivate *pclass = PANGO_FONT_GET_CLASS_PRIVATE (font);
+
+  pclass->get_matrix (font, matrix);
+}
+
 gboolean
 pango_font_is_hinted (PangoFont *font)
 {
