@@ -111,9 +111,12 @@ pango_hb_font_get_nominal_glyph (hb_font_t      *font,
         }
 
       if ((context->show_flags & PANGO_SHOW_IGNORABLES) != 0 &&
-          pango_get_ignorable (unicode))
+          pango_is_default_ignorable (unicode))
         {
-          *glyph = PANGO_GET_UNKNOWN_GLYPH (unicode);
+          if (pango_get_ignorable (unicode))
+            *glyph = PANGO_GET_UNKNOWN_GLYPH (unicode);
+          else
+            *glyph = PANGO_GLYPH_EMPTY;
           return TRUE;
         }
 
@@ -169,7 +172,10 @@ pango_hb_font_get_glyph_v_advance (hb_font_t      *font,
 
   pango_font_get_glyph_extents (context->font, glyph, NULL, &logical);
 
-  return logical.height;
+  if (hb_font_get_glyph_v_advance (context->parent, glyph) < 0)
+    return - logical.height;
+  else
+    return logical.height;
 }
 
 static hb_bool_t
